@@ -123,6 +123,94 @@ is($tt_mobile->is_geographic(),
    (is_libphonenumber() ? 0 : 1),
    "$CLASS->new('$tt_mobile_numb')->is_geographic()");
 
+note("operator");
+skip_if_libphonenumber("Stubs don't support operator", 1, sub {
+    is($CLASS->new('+1 416 392 2489')->operator(), 'Bell Canada', "Canada");
+
+    is($CLASS->new('+1 216 208 0000')->operator(), 'ONVOY, LLC - OH',
+        "Unicode en-dash in some US data converted to hyphen");
+
+    my @codes_seen = ();
+    foreach my $tuple (
+        ['+1 242 225 0000' => 'BAHAMAS TELECOMMUNICATIONS CORP.'],
+        ['+1 246 220 0000' => 'CABLE & WIRELESS BARBADOS'],
+        ['+1 264 222 0000' => 'CABLE & WIRELESS - ANGUILLA'],
+        ['+1 268 222 0000' => 'CABLE & WIRELESS - ANTIGUA'],
+        ['+1 284 229 0000' => 'CABLE & WIRELESS - TORTOLA'],
+        ['+1 340 774 5666' => 'VIRGIN ISLANDS TEL. CORP. DBA INNOVATIVE TELEPHONE'],
+        ['+1 345 222 0000' => 'CABLE & WIRELESS - CAYMAN ISLANDS'],
+        ['+1 441 222 0000' => 'Bermuda Cablevision Ltd'],
+        ['+1 473 230 0000' => 'COLUMBUS COMMUNICATIONS (GRENADA) LIMITED'],
+        ['+1 649 231 0000' => 'CABLE & WIRELESS - TURKS & CAICOS'],
+        # No data yet.
+        # checked on 2018-12-16
+        # next check due 2019-03-01 (quarterly) until there's data
+        # ['+1 658 ??? 0000' => '???'],
+        ['+1 664 349 0000' => 'CABLE & WIRELESS - MONTSERRAT'],
+        ['+1 670 233 0000' => 'MICRONESIAN TELECOMMUNICATIONS CORP.'],
+        ['+1 671 472 7679' => 'TELEGUAM HOLDINGS, LLC'],
+        ['+1 684 248 0000' => 'AST TELECOM, LLC - AS'],
+        ['+1 721 510 0000' => 'UTS RADCOMM'],
+        ['+1 758 234 0000' => 'CABLE & WIRELESS - ST. LUCIA, LTD'],
+        ['+1 767 221 0000' => 'DIGICEL (GRENADA) LIMITED'],
+        ['+1 784 266 0000' => 'CABLE & WIRELESS - ST. VINCENT'],
+        ['+1 787 200 0000' => 'LIBERTY CABLEVISION OF PUERTO RICO, LLC - PR'],
+        ['+1 809 202 0000' => 'ECONOMITEL, C. POR A. - DR'],
+        ['+1 829 201 0000' => 'CODETEL'],
+        ['+1 849 201 0000' => 'CODETEL'],
+        ['+1 868 201 0000' => 'Open Telecom Ltd'],
+        ['+1 869 212 0000' => 'ST KITTS NEVIS TELEPHONE - NEVIS'],
+        ['+1 876 202 0000' => 'JAMAICA TELEPHONE CO.'],
+        ['+1 939 201 0000' => 'AT&T, INC. - PR'],
+    ) {
+        my($number, $op) = @{$tuple};
+        push @codes_seen, substr($number, 3, 3);
+        is($CLASS->new($number)->operator(), $op, "$number has the right operator");
+    }
+    is_deeply(
+        \@codes_seen,
+        [grep { $_ != 658 } Number::Phone::Country::_non_US_CA_area_codes()],
+        "Oh good, the database contains data for all the non-US/CA area codes (except 658, for which no data are yet available)"
+    );
+
+    # checked on 2018-12-14 that these are consolidated ten-thousand blocks
+    # next check due 2019-12-01 (annually)
+    is($CLASS->new('+1 630 847 0000')->operator(), 'YMAX COMMUNICATIONS CORP. - IL', 'USA, thousands blocks all for same operator, so consolidated into one to save space in database');
+    # checked on 2018-12-14
+    # next check due 2019-12-01 (annually)
+    is($CLASS->new('+1 242 367 0000')->operator(), 'BAHAMAS TELECOMMUNICATIONS CORP.', 'Bahamas, thousands blocks all for same operator, so consolidated into one to save space in database');
+
+    foreach my $number(
+        [ 'Bahamas', '+1 242 331 0000', undef ],
+        [ 'Bahamas', '+1 242 331 1000', undef ],
+        [ 'Bahamas', '+1 242 331 2000', 'BAHAMAS TELECOMMUNICATIONS CORP.' ],
+        [ 'Bahamas', '+1 242 331 3000', 'BAHAMAS TELECOMMUNICATIONS CORP.' ],
+        [ 'Bahamas', '+1 242 331 4000', undef ],
+        [ 'Bahamas', '+1 242 331 5000', undef ],
+        [ 'Bahamas', '+1 242 331 6000', undef ],
+        [ 'Bahamas', '+1 242 331 7000', undef ],
+        [ 'Bahamas', '+1 242 331 8000', undef ],
+        [ 'Bahamas', '+1 242 331 9000', undef ],
+        [ 'USA',     '+1 512 373 0000', 'SPRINT SPECTRUM L.P.' ],
+        [ 'USA',     '+1 512 373 1000', undef ],
+        [ 'USA',     '+1 512 373 2000', 'SPRINT SPECTRUM L.P.', ],
+        [ 'USA',     '+1 512 373 3000', 'TIME WARNER CBLE INFO SVC (TX) DBA TIME WARNER CBL', ],
+        [ 'USA',     '+1 512 373 4000', undef ],
+        [ 'USA',     '+1 512 373 5000', 'SPRINT SPECTRUM L.P.' ],
+        [ 'USA',     '+1 512 373 6000', 'SPRINT SPECTRUM L.P.' ],
+        [ 'USA',     '+1 512 373 7000', undef ],
+        [ 'USA',     '+1 512 373 8000', 'TIME WARNER CBLE INFO SVC (TX) DBA TIME WARNER CBL' ],
+        [ 'USA',     '+1 512 373 9000', 'SPRINT SPECTRUM L.P.' ]
+    ) {
+        is(
+            $CLASS->new($number->[1])->operator(),
+            $number->[2],
+            $number->[0].', thousand block, '.$number->[1].', '.
+                (defined($number->[2]) ? 'allocated' : 'unallocated')
+        );
+    }
+});
+
 note("is_government");
 skip_if_libphonenumber("Stubs don't support is_government", 1, sub {
     is($CLASS->new('+17106274387')->is_government(), 1, "710 is the Feds man");
